from mongoengine import *


class EUR(EmbeddedDocument):
    meta = {'strict': False}
    price = FloatField()
    volume_24h = FloatField()
    percent_change_1h = FloatField()
    percent_change_24h = FloatField()
    percent_change_7d = FloatField()
    market_cap = FloatField()
    last_updated = StringField()


class EURQuote(EmbeddedDocument):
    meta = {'strict': False}
    eur = EmbeddedDocumentField(EUR, db_field='EUR')


class Coin(EmbeddedDocument):
    meta = {'strict': False}
    id = IntField()
    name = StringField()
    symbol = StringField()
    quote = EmbeddedDocumentField(EURQuote, db_field='quote')


class Status(EmbeddedDocument):
    meta = {'strict': False}
    timestamp = StringField()


class prices(Document):
    meta = {'strict': False}
    _id = IntField(db_field='_id')
    coins = EmbeddedDocumentListField(Coin, db_field='data')
    status = ListField(EmbeddedDocumentListField(Status, db_field='status'))





from keyring import get_password
from mongoengine import *
from cryptomodel.operations import OPERATIONS
from cryptomodel.order_types import ORDER_TYPES
from cryptomodel.transaction_types import TRANSACTION_TYPES


class user_settings(Document):
    meta = {'strict': False}
    user_id = IntField()
    preferred_currency = StringField()
    source_id = ObjectIdField()
    operation = StringField(choices=OPERATIONS.choices())


class user_notification(Document):
    meta = {'strict': False}
    user_id = IntField()
    user_name = StringField()
    user_email = StringField()
    expression_to_evaluate = StringField()
    check_every_seconds = LongField()
    check_times = LongField()
    is_active = BooleanField()
    channel_type = StringField()
    fields_to_send = StringField()
    source_id = ObjectIdField()
    operation = StringField(choices=OPERATIONS.choices())


class user_transaction(Document):
    meta = {'strict': False}
    user_id = IntField()
    volume = FloatField()
    symbol = StringField()
    value = FloatField()
    price = FloatField()
    date = DateField()
    source = StringField()
    currency = StringField()
    order_type = StringField(choices=ORDER_TYPES.choices())
    type = StringField(choices=TRANSACTION_TYPES.choices())
    source_id = ObjectIdField()
    operation = StringField(choices=OPERATIONS.choices())
    is_valid = BooleanField(default=True)
    invalid_reason = StringField(default="")

    def validate_symbol(self, symbols):
        if symbols is None:
            self.is_valid = True
            self.invalid_reason = ""
        if self.symbol not in symbols:
            self.is_valid = False
            self.invalid_reason = "symbol does not exist in list value:" + self.symbol
        return self.is_valid


class user_channel(Document):
    meta = {'strict': False}
    user_id = IntField()
    channel_type = StringField()
    chat_id = StringField()
    user_email = StringField()
    source_id = ObjectIdField()
    operation = StringField(choices=OPERATIONS.choices())

    def set_token(self):
        self.token = get_password(self.notification_type, 'token')



from enum import Enum


class TRANSACTION_TYPES(Enum):
    DEPOSIT = "DEPOSIT"
    TRADE = "TRADE"
    WITHDRAWAL = "WITHDRAWAL"

    @classmethod
    def choices(cls):
        return tuple((i.name, i.value) for i in cls)



import setuptools

from distutils.core import setup


with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='cryptomodel-athanikos',
    version="2.4.3",
    license='MIT License',
    author='Nikos Athanasakis',
    packages=setuptools.find_packages(),
    author_email='athanikos@gmail.com',
    description='Model for CryptoStore and CoinMarketCap Collections for Mongo db',
    tests_require=['pytest'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
